/**
 */
package org.etsi.mts.tdl.util;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notifier;

import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;

import org.eclipse.emf.ecore.EObject;

import org.etsi.mts.tdl.Action;
import org.etsi.mts.tdl.ActionBehaviour;
import org.etsi.mts.tdl.ActionReference;
import org.etsi.mts.tdl.AlternativeBehaviour;
import org.etsi.mts.tdl.Annotation;
import org.etsi.mts.tdl.AnnotationType;
import org.etsi.mts.tdl.AnyValue;
import org.etsi.mts.tdl.AnyValueOrOmit;
import org.etsi.mts.tdl.Assertion;
import org.etsi.mts.tdl.Assignment;
import org.etsi.mts.tdl.AtomicBehaviour;
import org.etsi.mts.tdl.Behaviour;
import org.etsi.mts.tdl.BehaviourDescription;
import org.etsi.mts.tdl.Block;
import org.etsi.mts.tdl.BoundedLoopBehaviour;
import org.etsi.mts.tdl.Break;
import org.etsi.mts.tdl.CollectionDataInstance;
import org.etsi.mts.tdl.CollectionDataType;
import org.etsi.mts.tdl.CombinedBehaviour;
import org.etsi.mts.tdl.Comment;
import org.etsi.mts.tdl.ComponentInstance;
import org.etsi.mts.tdl.ComponentInstanceBinding;
import org.etsi.mts.tdl.ComponentType;
import org.etsi.mts.tdl.CompoundBehaviour;
import org.etsi.mts.tdl.ConditionalBehaviour;
import org.etsi.mts.tdl.Connection;
import org.etsi.mts.tdl.Constraint;
import org.etsi.mts.tdl.ConstraintType;
import org.etsi.mts.tdl.DataElementMapping;
import org.etsi.mts.tdl.DataElementUse;
import org.etsi.mts.tdl.DataInstance;
import org.etsi.mts.tdl.DataInstanceUse;
import org.etsi.mts.tdl.DataResourceMapping;
import org.etsi.mts.tdl.DataType;
import org.etsi.mts.tdl.DataUse;
import org.etsi.mts.tdl.DefaultBehaviour;
import org.etsi.mts.tdl.DynamicDataUse;
import org.etsi.mts.tdl.Element;
import org.etsi.mts.tdl.ElementImport;
import org.etsi.mts.tdl.EnumDataType;
import org.etsi.mts.tdl.ExceptionalBehaviour;
import org.etsi.mts.tdl.Extension;
import org.etsi.mts.tdl.FormalParameter;
import org.etsi.mts.tdl.FormalParameterUse;
import org.etsi.mts.tdl.Function;
import org.etsi.mts.tdl.FunctionCall;
import org.etsi.mts.tdl.GateInstance;
import org.etsi.mts.tdl.GateReference;
import org.etsi.mts.tdl.GateType;
import org.etsi.mts.tdl.InlineAction;
import org.etsi.mts.tdl.Interaction;
import org.etsi.mts.tdl.InterruptBehaviour;
import org.etsi.mts.tdl.LiteralValueUse;
import org.etsi.mts.tdl.LocalExpression;
import org.etsi.mts.tdl.MappableDataElement;
import org.etsi.mts.tdl.Member;
import org.etsi.mts.tdl.MemberAssignment;
import org.etsi.mts.tdl.MemberReference;
import org.etsi.mts.tdl.Message;
import org.etsi.mts.tdl.MultipleCombinedBehaviour;
import org.etsi.mts.tdl.NamedElement;
import org.etsi.mts.tdl.OmitValue;
import org.etsi.mts.tdl.OptionalBehaviour;
import org.etsi.mts.tdl.PackageableElement;
import org.etsi.mts.tdl.ParallelBehaviour;
import org.etsi.mts.tdl.Parameter;
import org.etsi.mts.tdl.ParameterBinding;
import org.etsi.mts.tdl.ParameterMapping;
import org.etsi.mts.tdl.PeriodicBehaviour;
import org.etsi.mts.tdl.PredefinedFunction;
import org.etsi.mts.tdl.PredefinedFunctionCall;
import org.etsi.mts.tdl.ProcedureCall;
import org.etsi.mts.tdl.ProcedureParameter;
import org.etsi.mts.tdl.ProcedureSignature;
import org.etsi.mts.tdl.Quiescence;
import org.etsi.mts.tdl.SimpleDataInstance;
import org.etsi.mts.tdl.SimpleDataType;
import org.etsi.mts.tdl.SingleCombinedBehaviour;
import org.etsi.mts.tdl.SpecialValueUse;
import org.etsi.mts.tdl.StaticDataUse;
import org.etsi.mts.tdl.Stop;
import org.etsi.mts.tdl.StructuredDataInstance;
import org.etsi.mts.tdl.StructuredDataType;
import org.etsi.mts.tdl.Target;
import org.etsi.mts.tdl.TestConfiguration;
import org.etsi.mts.tdl.TestDescription;
import org.etsi.mts.tdl.TestDescriptionReference;
import org.etsi.mts.tdl.TestObjective;
import org.etsi.mts.tdl.Time;
import org.etsi.mts.tdl.TimeConstraint;
import org.etsi.mts.tdl.TimeLabel;
import org.etsi.mts.tdl.TimeLabelUse;
import org.etsi.mts.tdl.TimeOperation;
import org.etsi.mts.tdl.TimeOut;
import org.etsi.mts.tdl.Timer;
import org.etsi.mts.tdl.TimerOperation;
import org.etsi.mts.tdl.TimerStart;
import org.etsi.mts.tdl.TimerStop;
import org.etsi.mts.tdl.UnboundedLoopBehaviour;
import org.etsi.mts.tdl.ValueAssignment;
import org.etsi.mts.tdl.Variable;
import org.etsi.mts.tdl.VariableUse;
import org.etsi.mts.tdl.VerdictAssignment;
import org.etsi.mts.tdl.Wait;
import org.etsi.mts.tdl.tdlPackage;

/**
 * <!-- begin-user-doc -->
 * The <b>Adapter Factory</b> for the model.
 * It provides an adapter <code>createXXX</code> method for each class of the model.
 * <!-- end-user-doc -->
 * @see org.etsi.mts.tdl.tdlPackage
 * @generated
 */
public class tdlAdapterFactory extends AdapterFactoryImpl
{
	/**
	 * The cached model package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static tdlPackage modelPackage;

	/**
	 * Creates an instance of the adapter factory.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public tdlAdapterFactory()
	{
		if (modelPackage == null)
		{
			modelPackage = tdlPackage.eINSTANCE;
		}
	}

	/**
	 * Returns whether this factory is applicable for the type of the object.
	 * <!-- begin-user-doc -->
	 * This implementation returns <code>true</code> if the object is either the model's package or is an instance object of the model.
	 * <!-- end-user-doc -->
	 * @return whether this factory is applicable for the type of the object.
	 * @generated
	 */
	@Override
	public boolean isFactoryForType(Object object)
	{
		if (object == modelPackage)
		{
			return true;
		}
		if (object instanceof EObject)
		{
			return ((EObject)object).eClass().getEPackage() == modelPackage;
		}
		return false;
	}

	/**
	 * The switch that delegates to the <code>createXXX</code> methods.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected tdlSwitch<Adapter> modelSwitch =
		new tdlSwitch<Adapter>()
		{
			@Override
			public Adapter caseElement(Element object)
			{
				return createElementAdapter();
			}
			@Override
			public Adapter caseComment(Comment object)
			{
				return createCommentAdapter();
			}
			@Override
			public Adapter caseAnnotation(Annotation object)
			{
				return createAnnotationAdapter();
			}
			@Override
			public Adapter caseAnnotationType(AnnotationType object)
			{
				return createAnnotationTypeAdapter();
			}
			@Override
			public Adapter casePackageableElement(PackageableElement object)
			{
				return createPackageableElementAdapter();
			}
			@Override
			public Adapter caseNamedElement(NamedElement object)
			{
				return createNamedElementAdapter();
			}
			@Override
			public Adapter casePackage(org.etsi.mts.tdl.Package object)
			{
				return createPackageAdapter();
			}
			@Override
			public Adapter caseElementImport(ElementImport object)
			{
				return createElementImportAdapter();
			}
			@Override
			public Adapter caseTestObjective(TestObjective object)
			{
				return createTestObjectiveAdapter();
			}
			@Override
			public Adapter caseDataInstance(DataInstance object)
			{
				return createDataInstanceAdapter();
			}
			@Override
			public Adapter caseMappableDataElement(MappableDataElement object)
			{
				return createMappableDataElementAdapter();
			}
			@Override
			public Adapter caseDataType(DataType object)
			{
				return createDataTypeAdapter();
			}
			@Override
			public Adapter caseDataResourceMapping(DataResourceMapping object)
			{
				return createDataResourceMappingAdapter();
			}
			@Override
			public Adapter caseDataElementMapping(DataElementMapping object)
			{
				return createDataElementMappingAdapter();
			}
			@Override
			public Adapter caseParameterMapping(ParameterMapping object)
			{
				return createParameterMappingAdapter();
			}
			@Override
			public Adapter caseParameter(Parameter object)
			{
				return createParameterAdapter();
			}
			@Override
			public Adapter caseSimpleDataType(SimpleDataType object)
			{
				return createSimpleDataTypeAdapter();
			}
			@Override
			public Adapter caseSimpleDataInstance(SimpleDataInstance object)
			{
				return createSimpleDataInstanceAdapter();
			}
			@Override
			public Adapter caseStructuredDataType(StructuredDataType object)
			{
				return createStructuredDataTypeAdapter();
			}
			@Override
			public Adapter caseMember(Member object)
			{
				return createMemberAdapter();
			}
			@Override
			public Adapter caseStructuredDataInstance(StructuredDataInstance object)
			{
				return createStructuredDataInstanceAdapter();
			}
			@Override
			public Adapter caseMemberAssignment(MemberAssignment object)
			{
				return createMemberAssignmentAdapter();
			}
			@Override
			public Adapter caseStaticDataUse(StaticDataUse object)
			{
				return createStaticDataUseAdapter();
			}
			@Override
			public Adapter caseDataUse(DataUse object)
			{
				return createDataUseAdapter();
			}
			@Override
			public Adapter caseParameterBinding(ParameterBinding object)
			{
				return createParameterBindingAdapter();
			}
			@Override
			public Adapter caseAction(Action object)
			{
				return createActionAdapter();
			}
			@Override
			public Adapter caseFormalParameter(FormalParameter object)
			{
				return createFormalParameterAdapter();
			}
			@Override
			public Adapter caseFunction(Function object)
			{
				return createFunctionAdapter();
			}
			@Override
			public Adapter caseFormalParameterUse(FormalParameterUse object)
			{
				return createFormalParameterUseAdapter();
			}
			@Override
			public Adapter caseDynamicDataUse(DynamicDataUse object)
			{
				return createDynamicDataUseAdapter();
			}
			@Override
			public Adapter caseVariable(Variable object)
			{
				return createVariableAdapter();
			}
			@Override
			public Adapter caseFunctionCall(FunctionCall object)
			{
				return createFunctionCallAdapter();
			}
			@Override
			public Adapter caseVariableUse(VariableUse object)
			{
				return createVariableUseAdapter();
			}
			@Override
			public Adapter caseComponentInstance(ComponentInstance object)
			{
				return createComponentInstanceAdapter();
			}
			@Override
			public Adapter caseComponentType(ComponentType object)
			{
				return createComponentTypeAdapter();
			}
			@Override
			public Adapter caseGateInstance(GateInstance object)
			{
				return createGateInstanceAdapter();
			}
			@Override
			public Adapter caseGateType(GateType object)
			{
				return createGateTypeAdapter();
			}
			@Override
			public Adapter caseTimer(Timer object)
			{
				return createTimerAdapter();
			}
			@Override
			public Adapter caseOmitValue(OmitValue object)
			{
				return createOmitValueAdapter();
			}
			@Override
			public Adapter caseSpecialValueUse(SpecialValueUse object)
			{
				return createSpecialValueUseAdapter();
			}
			@Override
			public Adapter caseAnyValue(AnyValue object)
			{
				return createAnyValueAdapter();
			}
			@Override
			public Adapter caseAnyValueOrOmit(AnyValueOrOmit object)
			{
				return createAnyValueOrOmitAdapter();
			}
			@Override
			public Adapter caseDataInstanceUse(DataInstanceUse object)
			{
				return createDataInstanceUseAdapter();
			}
			@Override
			public Adapter caseTime(Time object)
			{
				return createTimeAdapter();
			}
			@Override
			public Adapter caseTimeLabel(TimeLabel object)
			{
				return createTimeLabelAdapter();
			}
			@Override
			public Adapter caseTimerOperation(TimerOperation object)
			{
				return createTimerOperationAdapter();
			}
			@Override
			public Adapter caseAtomicBehaviour(AtomicBehaviour object)
			{
				return createAtomicBehaviourAdapter();
			}
			@Override
			public Adapter caseBehaviour(Behaviour object)
			{
				return createBehaviourAdapter();
			}
			@Override
			public Adapter caseTimeConstraint(TimeConstraint object)
			{
				return createTimeConstraintAdapter();
			}
			@Override
			public Adapter caseTimerStart(TimerStart object)
			{
				return createTimerStartAdapter();
			}
			@Override
			public Adapter caseTimerStop(TimerStop object)
			{
				return createTimerStopAdapter();
			}
			@Override
			public Adapter caseTimeOut(TimeOut object)
			{
				return createTimeOutAdapter();
			}
			@Override
			public Adapter caseTimeOperation(TimeOperation object)
			{
				return createTimeOperationAdapter();
			}
			@Override
			public Adapter caseWait(Wait object)
			{
				return createWaitAdapter();
			}
			@Override
			public Adapter caseQuiescence(Quiescence object)
			{
				return createQuiescenceAdapter();
			}
			@Override
			public Adapter caseGateReference(GateReference object)
			{
				return createGateReferenceAdapter();
			}
			@Override
			public Adapter caseTimeLabelUse(TimeLabelUse object)
			{
				return createTimeLabelUseAdapter();
			}
			@Override
			public Adapter caseTestConfiguration(TestConfiguration object)
			{
				return createTestConfigurationAdapter();
			}
			@Override
			public Adapter caseConnection(Connection object)
			{
				return createConnectionAdapter();
			}
			@Override
			public Adapter caseTestDescription(TestDescription object)
			{
				return createTestDescriptionAdapter();
			}
			@Override
			public Adapter caseBehaviourDescription(BehaviourDescription object)
			{
				return createBehaviourDescriptionAdapter();
			}
			@Override
			public Adapter caseBlock(Block object)
			{
				return createBlockAdapter();
			}
			@Override
			public Adapter caseCombinedBehaviour(CombinedBehaviour object)
			{
				return createCombinedBehaviourAdapter();
			}
			@Override
			public Adapter casePeriodicBehaviour(PeriodicBehaviour object)
			{
				return createPeriodicBehaviourAdapter();
			}
			@Override
			public Adapter caseExceptionalBehaviour(ExceptionalBehaviour object)
			{
				return createExceptionalBehaviourAdapter();
			}
			@Override
			public Adapter caseAlternativeBehaviour(AlternativeBehaviour object)
			{
				return createAlternativeBehaviourAdapter();
			}
			@Override
			public Adapter caseMultipleCombinedBehaviour(MultipleCombinedBehaviour object)
			{
				return createMultipleCombinedBehaviourAdapter();
			}
			@Override
			public Adapter caseParallelBehaviour(ParallelBehaviour object)
			{
				return createParallelBehaviourAdapter();
			}
			@Override
			public Adapter caseBoundedLoopBehaviour(BoundedLoopBehaviour object)
			{
				return createBoundedLoopBehaviourAdapter();
			}
			@Override
			public Adapter caseSingleCombinedBehaviour(SingleCombinedBehaviour object)
			{
				return createSingleCombinedBehaviourAdapter();
			}
			@Override
			public Adapter caseOptionalBehaviour(OptionalBehaviour object)
			{
				return createOptionalBehaviourAdapter();
			}
			@Override
			public Adapter caseUnboundedLoopBehaviour(UnboundedLoopBehaviour object)
			{
				return createUnboundedLoopBehaviourAdapter();
			}
			@Override
			public Adapter caseConditionalBehaviour(ConditionalBehaviour object)
			{
				return createConditionalBehaviourAdapter();
			}
			@Override
			public Adapter caseCompoundBehaviour(CompoundBehaviour object)
			{
				return createCompoundBehaviourAdapter();
			}
			@Override
			public Adapter caseDefaultBehaviour(DefaultBehaviour object)
			{
				return createDefaultBehaviourAdapter();
			}
			@Override
			public Adapter caseInterruptBehaviour(InterruptBehaviour object)
			{
				return createInterruptBehaviourAdapter();
			}
			@Override
			public Adapter caseTarget(Target object)
			{
				return createTargetAdapter();
			}
			@Override
			public Adapter caseVerdictAssignment(VerdictAssignment object)
			{
				return createVerdictAssignmentAdapter();
			}
			@Override
			public Adapter caseAssertion(Assertion object)
			{
				return createAssertionAdapter();
			}
			@Override
			public Adapter caseStop(Stop object)
			{
				return createStopAdapter();
			}
			@Override
			public Adapter caseBreak(Break object)
			{
				return createBreakAdapter();
			}
			@Override
			public Adapter caseAssignment(Assignment object)
			{
				return createAssignmentAdapter();
			}
			@Override
			public Adapter caseActionBehaviour(ActionBehaviour object)
			{
				return createActionBehaviourAdapter();
			}
			@Override
			public Adapter caseInlineAction(InlineAction object)
			{
				return createInlineActionAdapter();
			}
			@Override
			public Adapter caseActionReference(ActionReference object)
			{
				return createActionReferenceAdapter();
			}
			@Override
			public Adapter caseTestDescriptionReference(TestDescriptionReference object)
			{
				return createTestDescriptionReferenceAdapter();
			}
			@Override
			public Adapter caseComponentInstanceBinding(ComponentInstanceBinding object)
			{
				return createComponentInstanceBindingAdapter();
			}
			@Override
			public Adapter caseInteraction(Interaction object)
			{
				return createInteractionAdapter();
			}
			@Override
			public Adapter caseMessage(Message object)
			{
				return createMessageAdapter();
			}
			@Override
			public Adapter casePredefinedFunction(PredefinedFunction object)
			{
				return createPredefinedFunctionAdapter();
			}
			@Override
			public Adapter caseMemberReference(MemberReference object)
			{
				return createMemberReferenceAdapter();
			}
			@Override
			public Adapter casePredefinedFunctionCall(PredefinedFunctionCall object)
			{
				return createPredefinedFunctionCallAdapter();
			}
			@Override
			public Adapter caseLocalExpression(LocalExpression object)
			{
				return createLocalExpressionAdapter();
			}
			@Override
			public Adapter caseValueAssignment(ValueAssignment object)
			{
				return createValueAssignmentAdapter();
			}
			@Override
			public Adapter caseProcedureCall(ProcedureCall object)
			{
				return createProcedureCallAdapter();
			}
			@Override
			public Adapter caseProcedureSignature(ProcedureSignature object)
			{
				return createProcedureSignatureAdapter();
			}
			@Override
			public Adapter caseProcedureParameter(ProcedureParameter object)
			{
				return createProcedureParameterAdapter();
			}
			@Override
			public Adapter caseCollectionDataType(CollectionDataType object)
			{
				return createCollectionDataTypeAdapter();
			}
			@Override
			public Adapter caseCollectionDataInstance(CollectionDataInstance object)
			{
				return createCollectionDataInstanceAdapter();
			}
			@Override
			public Adapter caseExtension(Extension object)
			{
				return createExtensionAdapter();
			}
			@Override
			public Adapter caseLiteralValueUse(LiteralValueUse object)
			{
				return createLiteralValueUseAdapter();
			}
			@Override
			public Adapter caseConstraintType(ConstraintType object)
			{
				return createConstraintTypeAdapter();
			}
			@Override
			public Adapter caseConstraint(Constraint object)
			{
				return createConstraintAdapter();
			}
			@Override
			public Adapter caseEnumDataType(EnumDataType object)
			{
				return createEnumDataTypeAdapter();
			}
			@Override
			public Adapter caseDataElementUse(DataElementUse object)
			{
				return createDataElementUseAdapter();
			}
			@Override
			public Adapter defaultCase(EObject object)
			{
				return createEObjectAdapter();
			}
		};

	/**
	 * Creates an adapter for the <code>target</code>.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param target the object to adapt.
	 * @return the adapter for the <code>target</code>.
	 * @generated
	 */
	@Override
	public Adapter createAdapter(Notifier target)
	{
		return modelSwitch.doSwitch((EObject)target);
	}


	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Element <em>Element</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Element
	 * @generated
	 */
	public Adapter createElementAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Comment <em>Comment</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Comment
	 * @generated
	 */
	public Adapter createCommentAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Annotation <em>Annotation</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Annotation
	 * @generated
	 */
	public Adapter createAnnotationAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.AnnotationType <em>Annotation Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.AnnotationType
	 * @generated
	 */
	public Adapter createAnnotationTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.PackageableElement <em>Packageable Element</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.PackageableElement
	 * @generated
	 */
	public Adapter createPackageableElementAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.NamedElement <em>Named Element</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.NamedElement
	 * @generated
	 */
	public Adapter createNamedElementAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Package <em>Package</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Package
	 * @generated
	 */
	public Adapter createPackageAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ElementImport <em>Element Import</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ElementImport
	 * @generated
	 */
	public Adapter createElementImportAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TestObjective <em>Test Objective</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TestObjective
	 * @generated
	 */
	public Adapter createTestObjectiveAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataInstance <em>Data Instance</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataInstance
	 * @generated
	 */
	public Adapter createDataInstanceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.MappableDataElement <em>Mappable Data Element</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.MappableDataElement
	 * @generated
	 */
	public Adapter createMappableDataElementAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataType <em>Data Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataType
	 * @generated
	 */
	public Adapter createDataTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataResourceMapping <em>Data Resource Mapping</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataResourceMapping
	 * @generated
	 */
	public Adapter createDataResourceMappingAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataElementMapping <em>Data Element Mapping</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataElementMapping
	 * @generated
	 */
	public Adapter createDataElementMappingAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ParameterMapping <em>Parameter Mapping</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ParameterMapping
	 * @generated
	 */
	public Adapter createParameterMappingAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Parameter <em>Parameter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Parameter
	 * @generated
	 */
	public Adapter createParameterAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.SimpleDataType <em>Simple Data Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.SimpleDataType
	 * @generated
	 */
	public Adapter createSimpleDataTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.SimpleDataInstance <em>Simple Data Instance</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.SimpleDataInstance
	 * @generated
	 */
	public Adapter createSimpleDataInstanceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.StructuredDataType <em>Structured Data Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.StructuredDataType
	 * @generated
	 */
	public Adapter createStructuredDataTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Member <em>Member</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Member
	 * @generated
	 */
	public Adapter createMemberAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.StructuredDataInstance <em>Structured Data Instance</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.StructuredDataInstance
	 * @generated
	 */
	public Adapter createStructuredDataInstanceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.MemberAssignment <em>Member Assignment</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.MemberAssignment
	 * @generated
	 */
	public Adapter createMemberAssignmentAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.StaticDataUse <em>Static Data Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.StaticDataUse
	 * @generated
	 */
	public Adapter createStaticDataUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataUse <em>Data Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataUse
	 * @generated
	 */
	public Adapter createDataUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ParameterBinding <em>Parameter Binding</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ParameterBinding
	 * @generated
	 */
	public Adapter createParameterBindingAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Action <em>Action</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Action
	 * @generated
	 */
	public Adapter createActionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.FormalParameter <em>Formal Parameter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.FormalParameter
	 * @generated
	 */
	public Adapter createFormalParameterAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Function <em>Function</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Function
	 * @generated
	 */
	public Adapter createFunctionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.FormalParameterUse <em>Formal Parameter Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.FormalParameterUse
	 * @generated
	 */
	public Adapter createFormalParameterUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DynamicDataUse <em>Dynamic Data Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DynamicDataUse
	 * @generated
	 */
	public Adapter createDynamicDataUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Variable <em>Variable</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Variable
	 * @generated
	 */
	public Adapter createVariableAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.FunctionCall <em>Function Call</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.FunctionCall
	 * @generated
	 */
	public Adapter createFunctionCallAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.VariableUse <em>Variable Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.VariableUse
	 * @generated
	 */
	public Adapter createVariableUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ComponentInstance <em>Component Instance</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ComponentInstance
	 * @generated
	 */
	public Adapter createComponentInstanceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ComponentType <em>Component Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ComponentType
	 * @generated
	 */
	public Adapter createComponentTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.GateInstance <em>Gate Instance</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.GateInstance
	 * @generated
	 */
	public Adapter createGateInstanceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.GateType <em>Gate Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.GateType
	 * @generated
	 */
	public Adapter createGateTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Timer <em>Timer</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Timer
	 * @generated
	 */
	public Adapter createTimerAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.OmitValue <em>Omit Value</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.OmitValue
	 * @generated
	 */
	public Adapter createOmitValueAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.SpecialValueUse <em>Special Value Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.SpecialValueUse
	 * @generated
	 */
	public Adapter createSpecialValueUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.AnyValue <em>Any Value</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.AnyValue
	 * @generated
	 */
	public Adapter createAnyValueAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.AnyValueOrOmit <em>Any Value Or Omit</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.AnyValueOrOmit
	 * @generated
	 */
	public Adapter createAnyValueOrOmitAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataInstanceUse <em>Data Instance Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataInstanceUse
	 * @generated
	 */
	public Adapter createDataInstanceUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Time <em>Time</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Time
	 * @generated
	 */
	public Adapter createTimeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimeLabel <em>Time Label</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimeLabel
	 * @generated
	 */
	public Adapter createTimeLabelAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimerOperation <em>Timer Operation</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimerOperation
	 * @generated
	 */
	public Adapter createTimerOperationAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.AtomicBehaviour <em>Atomic Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.AtomicBehaviour
	 * @generated
	 */
	public Adapter createAtomicBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Behaviour <em>Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Behaviour
	 * @generated
	 */
	public Adapter createBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimeConstraint <em>Time Constraint</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimeConstraint
	 * @generated
	 */
	public Adapter createTimeConstraintAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimerStart <em>Timer Start</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimerStart
	 * @generated
	 */
	public Adapter createTimerStartAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimerStop <em>Timer Stop</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimerStop
	 * @generated
	 */
	public Adapter createTimerStopAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimeOut <em>Time Out</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimeOut
	 * @generated
	 */
	public Adapter createTimeOutAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimeOperation <em>Time Operation</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimeOperation
	 * @generated
	 */
	public Adapter createTimeOperationAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Wait <em>Wait</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Wait
	 * @generated
	 */
	public Adapter createWaitAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Quiescence <em>Quiescence</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Quiescence
	 * @generated
	 */
	public Adapter createQuiescenceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.GateReference <em>Gate Reference</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.GateReference
	 * @generated
	 */
	public Adapter createGateReferenceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TimeLabelUse <em>Time Label Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TimeLabelUse
	 * @generated
	 */
	public Adapter createTimeLabelUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TestConfiguration <em>Test Configuration</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TestConfiguration
	 * @generated
	 */
	public Adapter createTestConfigurationAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Connection <em>Connection</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Connection
	 * @generated
	 */
	public Adapter createConnectionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TestDescription <em>Test Description</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TestDescription
	 * @generated
	 */
	public Adapter createTestDescriptionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.BehaviourDescription <em>Behaviour Description</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.BehaviourDescription
	 * @generated
	 */
	public Adapter createBehaviourDescriptionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Block <em>Block</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Block
	 * @generated
	 */
	public Adapter createBlockAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.CombinedBehaviour <em>Combined Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.CombinedBehaviour
	 * @generated
	 */
	public Adapter createCombinedBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.PeriodicBehaviour <em>Periodic Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.PeriodicBehaviour
	 * @generated
	 */
	public Adapter createPeriodicBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ExceptionalBehaviour <em>Exceptional Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ExceptionalBehaviour
	 * @generated
	 */
	public Adapter createExceptionalBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.AlternativeBehaviour <em>Alternative Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.AlternativeBehaviour
	 * @generated
	 */
	public Adapter createAlternativeBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.MultipleCombinedBehaviour <em>Multiple Combined Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.MultipleCombinedBehaviour
	 * @generated
	 */
	public Adapter createMultipleCombinedBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ParallelBehaviour <em>Parallel Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ParallelBehaviour
	 * @generated
	 */
	public Adapter createParallelBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.BoundedLoopBehaviour <em>Bounded Loop Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.BoundedLoopBehaviour
	 * @generated
	 */
	public Adapter createBoundedLoopBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.SingleCombinedBehaviour <em>Single Combined Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.SingleCombinedBehaviour
	 * @generated
	 */
	public Adapter createSingleCombinedBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.OptionalBehaviour <em>Optional Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.OptionalBehaviour
	 * @generated
	 */
	public Adapter createOptionalBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.UnboundedLoopBehaviour <em>Unbounded Loop Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.UnboundedLoopBehaviour
	 * @generated
	 */
	public Adapter createUnboundedLoopBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ConditionalBehaviour <em>Conditional Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ConditionalBehaviour
	 * @generated
	 */
	public Adapter createConditionalBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.CompoundBehaviour <em>Compound Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.CompoundBehaviour
	 * @generated
	 */
	public Adapter createCompoundBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DefaultBehaviour <em>Default Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DefaultBehaviour
	 * @generated
	 */
	public Adapter createDefaultBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.InterruptBehaviour <em>Interrupt Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.InterruptBehaviour
	 * @generated
	 */
	public Adapter createInterruptBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Target <em>Target</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Target
	 * @generated
	 */
	public Adapter createTargetAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.VerdictAssignment <em>Verdict Assignment</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.VerdictAssignment
	 * @generated
	 */
	public Adapter createVerdictAssignmentAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Assertion <em>Assertion</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Assertion
	 * @generated
	 */
	public Adapter createAssertionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Stop <em>Stop</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Stop
	 * @generated
	 */
	public Adapter createStopAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Break <em>Break</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Break
	 * @generated
	 */
	public Adapter createBreakAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Assignment <em>Assignment</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Assignment
	 * @generated
	 */
	public Adapter createAssignmentAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ActionBehaviour <em>Action Behaviour</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ActionBehaviour
	 * @generated
	 */
	public Adapter createActionBehaviourAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.InlineAction <em>Inline Action</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.InlineAction
	 * @generated
	 */
	public Adapter createInlineActionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ActionReference <em>Action Reference</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ActionReference
	 * @generated
	 */
	public Adapter createActionReferenceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.TestDescriptionReference <em>Test Description Reference</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.TestDescriptionReference
	 * @generated
	 */
	public Adapter createTestDescriptionReferenceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ComponentInstanceBinding <em>Component Instance Binding</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ComponentInstanceBinding
	 * @generated
	 */
	public Adapter createComponentInstanceBindingAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Interaction <em>Interaction</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Interaction
	 * @generated
	 */
	public Adapter createInteractionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Message <em>Message</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Message
	 * @generated
	 */
	public Adapter createMessageAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.PredefinedFunction <em>Predefined Function</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.PredefinedFunction
	 * @generated
	 */
	public Adapter createPredefinedFunctionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.MemberReference <em>Member Reference</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.MemberReference
	 * @generated
	 */
	public Adapter createMemberReferenceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.PredefinedFunctionCall <em>Predefined Function Call</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.PredefinedFunctionCall
	 * @generated
	 */
	public Adapter createPredefinedFunctionCallAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.LocalExpression <em>Local Expression</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.LocalExpression
	 * @generated
	 */
	public Adapter createLocalExpressionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ValueAssignment <em>Value Assignment</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ValueAssignment
	 * @generated
	 */
	public Adapter createValueAssignmentAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ProcedureCall <em>Procedure Call</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ProcedureCall
	 * @generated
	 */
	public Adapter createProcedureCallAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ProcedureSignature <em>Procedure Signature</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ProcedureSignature
	 * @generated
	 */
	public Adapter createProcedureSignatureAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ProcedureParameter <em>Procedure Parameter</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ProcedureParameter
	 * @generated
	 */
	public Adapter createProcedureParameterAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.CollectionDataType <em>Collection Data Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.CollectionDataType
	 * @generated
	 */
	public Adapter createCollectionDataTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.CollectionDataInstance <em>Collection Data Instance</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.CollectionDataInstance
	 * @generated
	 */
	public Adapter createCollectionDataInstanceAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Extension <em>Extension</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Extension
	 * @generated
	 */
	public Adapter createExtensionAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.LiteralValueUse <em>Literal Value Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.LiteralValueUse
	 * @generated
	 */
	public Adapter createLiteralValueUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.ConstraintType <em>Constraint Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.ConstraintType
	 * @generated
	 */
	public Adapter createConstraintTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.Constraint <em>Constraint</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.Constraint
	 * @generated
	 */
	public Adapter createConstraintAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.EnumDataType <em>Enum Data Type</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.EnumDataType
	 * @generated
	 */
	public Adapter createEnumDataTypeAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for an object of class '{@link org.etsi.mts.tdl.DataElementUse <em>Data Element Use</em>}'.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null so that we can easily ignore cases;
	 * it's useful to ignore a case when inheritance will catch all the cases anyway.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see org.etsi.mts.tdl.DataElementUse
	 * @generated
	 */
	public Adapter createDataElementUseAdapter()
	{
		return null;
	}

	/**
	 * Creates a new adapter for the default case.
	 * <!-- begin-user-doc -->
	 * This default implementation returns null.
	 * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @generated
	 */
	public Adapter createEObjectAdapter()
	{
		return null;
	}

} //tdlAdapterFactory
